##  Related Information
  * [Tech Categories in the Reference Catalog](https://help.sap.com/docs/leanix/ea/tech-categories-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "Tech categories in the reference catalog enable you to adopt the Technology Business Management \(TBM\) Taxonomy.")
  * [IT Component Modeling Guidelines](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model IT components. This includes best practices and applicable use cases, and common antipatterns.")


YesNo
Send
